@@ -22,18 +22,21 @@ from rvbd.shark._connection import SharkConnection
 from rvbd.shark._exceptions import SharkException
 from rvbd.shark._api_helpers import SharkAPIVersions
 from rvbd.shark._api4 import API4_0
+from rvbd.shark._api5 import API5_0
 from rvbd.common.utils import ColumnProxy
-from rvbd.shark._class_mapping import Classesv4, Classes
+from rvbd.shark._class_mapping import Classesv4, Classes, Classesv5
 
 
 FILTERS_MAP = {}
 
 API_TABLE = {
     "4.0" : API4_0,
+    "5.0" : API5_0
     }
 
 CLASS_TABLE = {
-    '4.0': Classesv4
+    '4.0': Classesv4,
+    '5.0': Classesv5
     }
 
 
@@ -78,7 +81,7 @@ class Shark(Service):
 
         super(Shark, self).__init__("shark", host, port=port, auth=auth,
                                     force_ssl=force_ssl, versions=versions)
-
+        
         self.api = API_TABLE[str(self.api_version)](self)
         self.classes = CLASS_TABLE[str(self.api_version)]()
         #these module may not be available
@@ -237,7 +240,8 @@ class Shark(Service):
 
     def create_view(self, src, columns, filters=None,
                     start_time=None, end_time=None,
-                    name=None, charts=None, sync=True):
+                    name=None, charts=None, sync=True,
+                    sampling_time_msec=None):
         """ Create a new view on this Shark.
 
         `src` identifies the source of packets to be analyzed.
@@ -265,7 +269,7 @@ class Shark(Service):
             filterobjs.extend([filt.bind(self) for filt in filters])
 
         view = self.classes.View._create(self, src, columns, filterobjs, name=name,
-                                             sync=sync)
+                                         sync=sync, sampling_time_msec=sampling_time_msec)
         self._add_view(view)
         return view
 
@@ -529,11 +533,13 @@ class Shark(Service):
 
     def restart(self):
         """Restart the Shark Appliance.
+        This will issue a system reboot.
         """
         self.api.system.restart({'type':'SHARK'})
 
     def restart_probe(self):
         """Restart the Shark probe.
+        This will restart the Pilot server only.
         """
         self.api.system.restart({'type':'PROBE'})
 
@@ -608,3 +614,15 @@ class Shark(Service):
         if case_id:
             config['case_id'] = int(case_id)
         return self.api.system.get_sysdump(path, config)
+    
+    @property
+    def version(self):
+        """Returns the Shark software version
+        """
+        return self.api.common.info().get('sw_version')
+
+    @property
+    def model(self):
+        """Returns the Shark software model
+        """
+        return self.api.common.info().get('model')
